@@ -1,5 +1,5 @@
 # Config File for ILL
-# $Id: ill.tcl,v 1.3 2001/02/21 13:46:53 adam Exp $
+# $Id: ill.tcl,v 1.3 2007-05-03 08:34:52 heikki Exp $
 # ----------------------------------------------------------
 # Prefix Specifications
 #  
@@ -48,6 +48,11 @@ set map($m,Overdue_0) Overdue_ExtensionS
 set membermap($m,APDU,ILL-Request) {APDU_ILL_Request illRequest}
 set membermap($m,APDU,ILL-Answer) {APDU_ILL_Answer illAnswer}
 
+# ----------------------------------------------------------
+set m OCLCILLRequestExtension
+# Filename
+set filename($m) oclc-ill-req-ext
+
 # ----------------------------------------------------------
 set m Z39.50-extendedService-ItemOrder-ItemRequest-1
 # Filename
